function initS = gmmb_em_init_kmeans(data, C);
% Create an initialization structure for EM,
% called from gmmb_em, see gmmb_em.
%
% 
% K-means clustering means, cluster weight and covariance
% the basic algorithm was invented by Greg Hamerly in order to find the 
% number of means for clustering. Here the final number of clusters is
% given and the clusters are splitted until the desired number of clusters
% is reached. This leads to a deterministic initialization of the GMM.

tries = 5;
N = size(data,1);	% number of points
D = size(data,2);	% dimensions

if C>1
    centres = NM4M_KMeans(data,C,0.001,'pca');
    for j=1:C
        vd = data - repmat(centres(j,:),size(data,1),1);
        cet(:,j) = sum(abs(vd).^2, 2);
    end
    % compute new cluster centers
    [a, pclass]=min(cet');
    lbl = pclass;
    mu = centres;
    % initialization has random nature, results will vary
else
    lbl = ones(N, 1);
    mu = mean(data, 1);
end

% covariances initialization
sigma = zeros(D,D,C);
weight = ones(C,1);
for c = 1:C
    sigma(:,:,c) = gmmb_covfixer(cov(data(lbl==c, :)));
    weight(c) = sum(lbl==c) / N;
end

initS = struct(...
    'mu', mu.', ...
    'sigma', sigma, ...
    'weight', weight ...
    );

